<?php
/**
 * Open Source Social Network
 * @link      https://www.opensource-socialnetwork.org/
 * @package   Pinned Posts
 * @author    Michael Zülsdorff <ossn@z-mans.net>
 * @copyright (C) Michael Zülsdorff
 * @license   GNU General Public License https://www.gnu.de/documents/gpl-2.0.en.html
 */

// prepare an empty variable in advance for the posts to pin
$pinned_posts = '';

// check if there's a list of saved post ids available at all?
if (isset($params["pinnedposts"]) && isset($params["pinnedposts"]->PinnedPosts)) {
	// yes, it is!
	// and extract the post ids from the comma sepatated list into an array
	$pinned_post_ids = explode(',', $params["pinnedposts"]->PinnedPosts);
	// check if the extraction was successful, (it may fail because of wrong separators e.g.)
	if (count($pinned_post_ids)) {
		// yep, our array contains one or more post ids
		// so let's fetch the posts from the database
		// the same way as done in OssnWall's ossn_com.php (see line #254 and below)
		// first, we need an instance of the OssnWall class, because GetPost() is a method of that class
		$wall  = new OssnWall();
		// and now we start looping through all post ids inside our array
		foreach ($pinned_post_ids as $pinned_post_id) {
			// and try to fetch that post from the ossn_objects database table
			$post  = $wall->GetPost($pinned_post_id);
			// we better check, if a record is returned indeed
			// because we maybe made a typo when saving the ids, or the post record was deleted in the meantime ;)
			if (!$post) {
				// no record found with an id like that, so ... fetch the next one
				continue;
			}
			// record found - but is it really a post?
			// note that the ossn_object table keeps various different records
			// thus a wrong id might result in something strange
			// and we better check for the correct type in advance
			if ($post->subtype != 'wall') {
				// oops, no post, so ... fetch the next id 
				continue;
			}
			// finally, we can be sure it IS in fact a post
			//
			// fortunately we don't have to care about formatting of the post, fetching comments and stuff here
			// because all that - as we already know from displaying a page with a single post - will be accomplished by a plugin of OssnWall
			$params['post'] = $post;
			// so let that plugin do its job and return the formatted post
			$contents = array(
				'content' => ossn_plugin_view('wall/pages/view', $params),
			);
			// now, we're copying every returned post from the loop into that prepared variable, and add a linebreak as a separator
			$pinned_posts = $pinned_posts  . $contents['content'] . '<br>';
		}
		// we're almost done! $pinned_posts contains all selected posts now
		// just one part that would lead to an unexpected result:
		// the class 'user-activity' is used as an anchor by the OssnAutoPagination component
		// in order to add the next 10 posts to the newsfeed when scrolling down 
		// and the plugin we used is actually returning that class!
		// so we need to replace it by a different class that doesn't trigger the auto-pagination -
		// because otherwise these 10 post would also be attached to our pinned posts ;)
		$pinned_posts = str_replace('user-activity', 'pinned-post', $pinned_posts);
		// ok, we're safe now: all occurences of 'user-activity' have been replaced by 'pinned-post'
	}
}	
?>

$(document).ready(function() {
	// add some outer formatting around the $pinned_posts HTML
	var  PinnedPosts = <?php echo json_encode('<div class="pinnedposts" style="text-align: justify;"> <strong>'.ossn_print('com:pinned:posts:title').'</strong> <p>'. $pinned_posts . '</p> </div>');?>;
	if ($('.newsfeed-middle .ossn-wall-container').length) {
		// and insert it on top of the newsfeed
		$(PinnedPosts).insertAfter('.newsfeed-middle .ossn-wall-container');
	}
});